# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_coordination.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_coordination.proto',
  package='Ydb.Coordination',
  syntax='proto3',
  serialized_options=b'\n\025tech.ydb.coordinationB\022CoordinationProtosP\001Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dprotos/ydb_coordination.proto\x12\x10Ydb.Coordination\x1a\x1aprotos/ydb_operation.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x17protos/ydb_scheme.proto\"\r\n\x0bUnsupported\"\xb2\x02\n\x06\x43onfig\x12\x0c\n\x04path\x18\x01 \x01(\t\x12 \n\x18self_check_period_millis\x18\x02 \x01(\r\x12#\n\x1bsession_grace_period_millis\x18\x03 \x01(\r\x12@\n\x15read_consistency_mode\x18\x04 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12\x42\n\x17\x61ttach_consistency_mode\x18\x05 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12M\n\x1arate_limiter_counters_mode\x18\x06 \x01(\x0e\x32).Ydb.Coordination.RateLimiterCountersMode\"g\n\x12SessionDescription\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x61ttached\x18\x04 \x01(\x08\"m\n\x10SemaphoreSession\x12\x10\n\x08order_id\x18\x05 \x01(\x04\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\xcc\x01\n\x14SemaphoreDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\r\n\x05\x63ount\x18\x07 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x11\n\tephemeral\x18\x04 \x01(\x08\x12\x32\n\x06owners\x18\x05 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\x12\x33\n\x07waiters\x18\x06 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\"\xd1\r\n\x0eSessionRequest\x12\x39\n\x04ping\x18\x01 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x39\n\x04pong\x18\x02 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x46\n\rsession_start\x18\x03 \x01(\x0b\x32-.Ydb.Coordination.SessionRequest.SessionStartH\x00\x12\x44\n\x0csession_stop\x18\x04 \x01(\x0b\x32,.Ydb.Coordination.SessionRequest.SessionStopH\x00\x12\x36\n\runsupported_5\x18\x05 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12N\n\x11\x61\x63quire_semaphore\x18\x07 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.AcquireSemaphoreH\x00\x12N\n\x11release_semaphore\x18\x08 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.ReleaseSemaphoreH\x00\x12P\n\x12\x64\x65scribe_semaphore\x18\t \x01(\x0b\x32\x32.Ydb.Coordination.SessionRequest.DescribeSemaphoreH\x00\x12L\n\x10\x63reate_semaphore\x18\n \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.CreateSemaphoreH\x00\x12L\n\x10update_semaphore\x18\x0b \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.UpdateSemaphoreH\x00\x12L\n\x10\x64\x65lete_semaphore\x18\x0c \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.DeleteSemaphoreH\x00\x12\x37\n\x0eunsupported_13\x18\r \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_14\x18\x0e \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_15\x18\x0f \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a\x85\x01\n\x0cSessionStart\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06seq_no\x18\x05 \x01(\x04\x12\x16\n\x0eprotection_key\x18\x06 \x01(\x0c\x1a\r\n\x0bSessionStop\x1ax\n\x10\x41\x63quireSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x11\n\tephemeral\x18\x06 \x01(\x08\x1a\x30\n\x10ReleaseSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x8c\x01\n\x11\x44\x65scribeSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0einclude_owners\x18\x03 \x01(\x08\x12\x17\n\x0finclude_waiters\x18\x04 \x01(\x08\x12\x12\n\nwatch_data\x18\x05 \x01(\x08\x12\x14\n\x0cwatch_owners\x18\x06 \x01(\x08\x1aL\n\x0f\x43reateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x1a=\n\x0fUpdateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x1a>\n\x0f\x44\x65leteSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x42\t\n\x07request\"\xd3\x14\n\x0fSessionResponse\x12:\n\x04ping\x18\x01 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12:\n\x04pong\x18\x02 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12<\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32).Ydb.Coordination.SessionResponse.FailureH\x00\x12K\n\x0fsession_started\x18\x04 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStartedH\x00\x12K\n\x0fsession_stopped\x18\x05 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStoppedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_7\x18\x07 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12^\n\x19\x61\x63quire_semaphore_pending\x18\x08 \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.AcquireSemaphorePendingH\x00\x12\\\n\x18\x61\x63quire_semaphore_result\x18\t \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.AcquireSemaphoreResultH\x00\x12\\\n\x18release_semaphore_result\x18\n \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.ReleaseSemaphoreResultH\x00\x12^\n\x19\x64\x65scribe_semaphore_result\x18\x0b \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.DescribeSemaphoreResultH\x00\x12`\n\x1a\x64\x65scribe_semaphore_changed\x18\x0c \x01(\x0b\x32:.Ydb.Coordination.SessionResponse.DescribeSemaphoreChangedH\x00\x12Z\n\x17\x63reate_semaphore_result\x18\r \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.CreateSemaphoreResultH\x00\x12Z\n\x17update_semaphore_result\x18\x0e \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.UpdateSemaphoreResultH\x00\x12Z\n\x17\x64\x65lete_semaphore_result\x18\x0f \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.DeleteSemaphoreResultH\x00\x12\x37\n\x0eunsupported_16\x18\x10 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_17\x18\x11 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_18\x18\x12 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a]\n\x07\x46\x61ilure\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a<\n\x0eSessionStarted\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x1a$\n\x0eSessionStopped\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x1a)\n\x17\x41\x63quireSemaphorePending\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x1a\x8e\x01\n\x16\x41\x63quireSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08\x61\x63quired\x18\x04 \x01(\x08\x1a\x8e\x01\n\x16ReleaseSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08released\x18\x04 \x01(\x08\x1a\xd9\x01\n\x17\x44\x65scribeSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x45\n\x15semaphore_description\x18\x04 \x01(\x0b\x32&.Ydb.Coordination.SemaphoreDescription\x12\x13\n\x0bwatch_added\x18\x05 \x01(\x08\x1aX\n\x18\x44\x65scribeSemaphoreChanged\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x14\n\x0c\x64\x61ta_changed\x18\x02 \x01(\x08\x12\x16\n\x0eowners_changed\x18\x03 \x01(\x08\x1a{\n\x15\x43reateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15UpdateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15\x44\x65leteSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessageB\n\n\x08response\"\x86\x01\n\x11\x43reateNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"B\n\x12\x43reateNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x01\n\x10\x41lterNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x41lterNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Z\n\x0f\x44ropNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"@\n\x10\x44ropNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"^\n\x13\x44\x65scribeNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"D\n\x14\x44\x65scribeNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x12\x44\x65scribeNodeResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config*h\n\x0f\x43onsistencyMode\x12\x1a\n\x16\x43ONSISTENCY_MODE_UNSET\x10\x00\x12\x1b\n\x17\x43ONSISTENCY_MODE_STRICT\x10\x01\x12\x1c\n\x18\x43ONSISTENCY_MODE_RELAXED\x10\x02*\x93\x01\n\x17RateLimiterCountersMode\x12$\n RATE_LIMITER_COUNTERS_MODE_UNSET\x10\x00\x12)\n%RATE_LIMITER_COUNTERS_MODE_AGGREGATED\x10\x01\x12\'\n#RATE_LIMITER_COUNTERS_MODE_DETAILED\x10\x02\x42q\n\x15tech.ydb.coordinationB\x12\x43oordinationProtosP\x01Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__scheme__pb2.DESCRIPTOR,])

_CONSISTENCYMODE = _descriptor.EnumDescriptor(
  name='ConsistencyMode',
  full_name='Ydb.Coordination.ConsistencyMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSISTENCY_MODE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSISTENCY_MODE_STRICT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSISTENCY_MODE_RELAXED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6137,
  serialized_end=6241,
)
_sym_db.RegisterEnumDescriptor(_CONSISTENCYMODE)

ConsistencyMode = enum_type_wrapper.EnumTypeWrapper(_CONSISTENCYMODE)
_RATELIMITERCOUNTERSMODE = _descriptor.EnumDescriptor(
  name='RateLimiterCountersMode',
  full_name='Ydb.Coordination.RateLimiterCountersMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RATE_LIMITER_COUNTERS_MODE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RATE_LIMITER_COUNTERS_MODE_AGGREGATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RATE_LIMITER_COUNTERS_MODE_DETAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6244,
  serialized_end=6391,
)
_sym_db.RegisterEnumDescriptor(_RATELIMITERCOUNTERSMODE)

RateLimiterCountersMode = enum_type_wrapper.EnumTypeWrapper(_RATELIMITERCOUNTERSMODE)
CONSISTENCY_MODE_UNSET = 0
CONSISTENCY_MODE_STRICT = 1
CONSISTENCY_MODE_RELAXED = 2
RATE_LIMITER_COUNTERS_MODE_UNSET = 0
RATE_LIMITER_COUNTERS_MODE_AGGREGATED = 1
RATE_LIMITER_COUNTERS_MODE_DETAILED = 2



_UNSUPPORTED = _descriptor.Descriptor(
  name='Unsupported',
  full_name='Ydb.Coordination.Unsupported',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=180,
)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='Ydb.Coordination.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.Config.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_check_period_millis', full_name='Ydb.Coordination.Config.self_check_period_millis', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_grace_period_millis', full_name='Ydb.Coordination.Config.session_grace_period_millis', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_consistency_mode', full_name='Ydb.Coordination.Config.read_consistency_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attach_consistency_mode', full_name='Ydb.Coordination.Config.attach_consistency_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limiter_counters_mode', full_name='Ydb.Coordination.Config.rate_limiter_counters_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=489,
)


_SESSIONDESCRIPTION = _descriptor.Descriptor(
  name='SessionDescription',
  full_name='Ydb.Coordination.SessionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Coordination.SessionDescription.session_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_millis', full_name='Ydb.Coordination.SessionDescription.timeout_millis', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Coordination.SessionDescription.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached', full_name='Ydb.Coordination.SessionDescription.attached', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=594,
)


_SEMAPHORESESSION = _descriptor.Descriptor(
  name='SemaphoreSession',
  full_name='Ydb.Coordination.SemaphoreSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='Ydb.Coordination.SemaphoreSession.order_id', index=0,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Coordination.SemaphoreSession.session_id', index=1,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_millis', full_name='Ydb.Coordination.SemaphoreSession.timeout_millis', index=2,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Coordination.SemaphoreSession.count', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Coordination.SemaphoreSession.data', index=4,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=705,
)


_SEMAPHOREDESCRIPTION = _descriptor.Descriptor(
  name='SemaphoreDescription',
  full_name='Ydb.Coordination.SemaphoreDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SemaphoreDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Coordination.SemaphoreDescription.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Coordination.SemaphoreDescription.count', index=2,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='Ydb.Coordination.SemaphoreDescription.limit', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeral', full_name='Ydb.Coordination.SemaphoreDescription.ephemeral', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owners', full_name='Ydb.Coordination.SemaphoreDescription.owners', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waiters', full_name='Ydb.Coordination.SemaphoreDescription.waiters', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=912,
)


_SESSIONREQUEST_PINGPONG = _descriptor.Descriptor(
  name='PingPong',
  full_name='Ydb.Coordination.SessionRequest.PingPong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='opaque', full_name='Ydb.Coordination.SessionRequest.PingPong.opaque', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1952,
  serialized_end=1978,
)

_SESSIONREQUEST_SESSIONSTART = _descriptor.Descriptor(
  name='SessionStart',
  full_name='Ydb.Coordination.SessionRequest.SessionStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.SessionRequest.SessionStart.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Coordination.SessionRequest.SessionStart.session_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_millis', full_name='Ydb.Coordination.SessionRequest.SessionStart.timeout_millis', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Coordination.SessionRequest.SessionStart.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='Ydb.Coordination.SessionRequest.SessionStart.seq_no', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protection_key', full_name='Ydb.Coordination.SessionRequest.SessionStart.protection_key', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1981,
  serialized_end=2114,
)

_SESSIONREQUEST_SESSIONSTOP = _descriptor.Descriptor(
  name='SessionStop',
  full_name='Ydb.Coordination.SessionRequest.SessionStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2116,
  serialized_end=2129,
)

_SESSIONREQUEST_ACQUIRESEMAPHORE = _descriptor.Descriptor(
  name='AcquireSemaphore',
  full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_millis', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.timeout_millis', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeral', full_name='Ydb.Coordination.SessionRequest.AcquireSemaphore.ephemeral', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2251,
)

_SESSIONREQUEST_RELEASESEMAPHORE = _descriptor.Descriptor(
  name='ReleaseSemaphore',
  full_name='Ydb.Coordination.SessionRequest.ReleaseSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.ReleaseSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.ReleaseSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2301,
)

_SESSIONREQUEST_DESCRIBESEMAPHORE = _descriptor.Descriptor(
  name='DescribeSemaphore',
  full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_owners', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.include_owners', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_waiters', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.include_waiters', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_data', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.watch_data', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_owners', full_name='Ydb.Coordination.SessionRequest.DescribeSemaphore.watch_owners', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2304,
  serialized_end=2444,
)

_SESSIONREQUEST_CREATESEMAPHORE = _descriptor.Descriptor(
  name='CreateSemaphore',
  full_name='Ydb.Coordination.SessionRequest.CreateSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.CreateSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.CreateSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='Ydb.Coordination.SessionRequest.CreateSemaphore.limit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Coordination.SessionRequest.CreateSemaphore.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2522,
)

_SESSIONREQUEST_UPDATESEMAPHORE = _descriptor.Descriptor(
  name='UpdateSemaphore',
  full_name='Ydb.Coordination.SessionRequest.UpdateSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.UpdateSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.UpdateSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Coordination.SessionRequest.UpdateSemaphore.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2524,
  serialized_end=2585,
)

_SESSIONREQUEST_DELETESEMAPHORE = _descriptor.Descriptor(
  name='DeleteSemaphore',
  full_name='Ydb.Coordination.SessionRequest.DeleteSemaphore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionRequest.DeleteSemaphore.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Coordination.SessionRequest.DeleteSemaphore.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='Ydb.Coordination.SessionRequest.DeleteSemaphore.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2587,
  serialized_end=2649,
)

_SESSIONREQUEST = _descriptor.Descriptor(
  name='SessionRequest',
  full_name='Ydb.Coordination.SessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping', full_name='Ydb.Coordination.SessionRequest.ping', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pong', full_name='Ydb.Coordination.SessionRequest.pong', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_start', full_name='Ydb.Coordination.SessionRequest.session_start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_stop', full_name='Ydb.Coordination.SessionRequest.session_stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_5', full_name='Ydb.Coordination.SessionRequest.unsupported_5', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_6', full_name='Ydb.Coordination.SessionRequest.unsupported_6', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquire_semaphore', full_name='Ydb.Coordination.SessionRequest.acquire_semaphore', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_semaphore', full_name='Ydb.Coordination.SessionRequest.release_semaphore', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='describe_semaphore', full_name='Ydb.Coordination.SessionRequest.describe_semaphore', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_semaphore', full_name='Ydb.Coordination.SessionRequest.create_semaphore', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_semaphore', full_name='Ydb.Coordination.SessionRequest.update_semaphore', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_semaphore', full_name='Ydb.Coordination.SessionRequest.delete_semaphore', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_13', full_name='Ydb.Coordination.SessionRequest.unsupported_13', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_14', full_name='Ydb.Coordination.SessionRequest.unsupported_14', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_15', full_name='Ydb.Coordination.SessionRequest.unsupported_15', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SESSIONREQUEST_PINGPONG, _SESSIONREQUEST_SESSIONSTART, _SESSIONREQUEST_SESSIONSTOP, _SESSIONREQUEST_ACQUIRESEMAPHORE, _SESSIONREQUEST_RELEASESEMAPHORE, _SESSIONREQUEST_DESCRIBESEMAPHORE, _SESSIONREQUEST_CREATESEMAPHORE, _SESSIONREQUEST_UPDATESEMAPHORE, _SESSIONREQUEST_DELETESEMAPHORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='Ydb.Coordination.SessionRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=915,
  serialized_end=2660,
)


_SESSIONRESPONSE_PINGPONG = _descriptor.Descriptor(
  name='PingPong',
  full_name='Ydb.Coordination.SessionResponse.PingPong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='opaque', full_name='Ydb.Coordination.SessionResponse.PingPong.opaque', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1952,
  serialized_end=1978,
)

_SESSIONRESPONSE_FAILURE = _descriptor.Descriptor(
  name='Failure',
  full_name='Ydb.Coordination.SessionResponse.Failure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.Failure.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.Failure.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4083,
  serialized_end=4176,
)

_SESSIONRESPONSE_SESSIONSTARTED = _descriptor.Descriptor(
  name='SessionStarted',
  full_name='Ydb.Coordination.SessionResponse.SessionStarted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Coordination.SessionResponse.SessionStarted.session_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_millis', full_name='Ydb.Coordination.SessionResponse.SessionStarted.timeout_millis', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4178,
  serialized_end=4238,
)

_SESSIONRESPONSE_SESSIONSTOPPED = _descriptor.Descriptor(
  name='SessionStopped',
  full_name='Ydb.Coordination.SessionResponse.SessionStopped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Coordination.SessionResponse.SessionStopped.session_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4240,
  serialized_end=4276,
)

_SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING = _descriptor.Descriptor(
  name='AcquireSemaphorePending',
  full_name='Ydb.Coordination.SessionResponse.AcquireSemaphorePending',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.AcquireSemaphorePending.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4278,
  serialized_end=4319,
)

_SESSIONRESPONSE_ACQUIRESEMAPHORERESULT = _descriptor.Descriptor(
  name='AcquireSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.AcquireSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.AcquireSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.AcquireSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.AcquireSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquired', full_name='Ydb.Coordination.SessionResponse.AcquireSemaphoreResult.acquired', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4322,
  serialized_end=4464,
)

_SESSIONRESPONSE_RELEASESEMAPHORERESULT = _descriptor.Descriptor(
  name='ReleaseSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='released', full_name='Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult.released', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4467,
  serialized_end=4609,
)

_SESSIONRESPONSE_DESCRIBESEMAPHORERESULT = _descriptor.Descriptor(
  name='DescribeSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='semaphore_description', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult.semaphore_description', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_added', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreResult.watch_added', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4612,
  serialized_end=4829,
)

_SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED = _descriptor.Descriptor(
  name='DescribeSemaphoreChanged',
  full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreChanged.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_changed', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreChanged.data_changed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owners_changed', full_name='Ydb.Coordination.SessionResponse.DescribeSemaphoreChanged.owners_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4831,
  serialized_end=4919,
)

_SESSIONRESPONSE_CREATESEMAPHORERESULT = _descriptor.Descriptor(
  name='CreateSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.CreateSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.CreateSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.CreateSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.CreateSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4921,
  serialized_end=5044,
)

_SESSIONRESPONSE_UPDATESEMAPHORERESULT = _descriptor.Descriptor(
  name='UpdateSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.UpdateSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.UpdateSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.UpdateSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.UpdateSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5046,
  serialized_end=5169,
)

_SESSIONRESPONSE_DELETESEMAPHORERESULT = _descriptor.Descriptor(
  name='DeleteSemaphoreResult',
  full_name='Ydb.Coordination.SessionResponse.DeleteSemaphoreResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Ydb.Coordination.SessionResponse.DeleteSemaphoreResult.req_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Coordination.SessionResponse.DeleteSemaphoreResult.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Coordination.SessionResponse.DeleteSemaphoreResult.issues', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5171,
  serialized_end=5294,
)

_SESSIONRESPONSE = _descriptor.Descriptor(
  name='SessionResponse',
  full_name='Ydb.Coordination.SessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ping', full_name='Ydb.Coordination.SessionResponse.ping', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pong', full_name='Ydb.Coordination.SessionResponse.pong', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='Ydb.Coordination.SessionResponse.failure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_started', full_name='Ydb.Coordination.SessionResponse.session_started', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_stopped', full_name='Ydb.Coordination.SessionResponse.session_stopped', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_6', full_name='Ydb.Coordination.SessionResponse.unsupported_6', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_7', full_name='Ydb.Coordination.SessionResponse.unsupported_7', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquire_semaphore_pending', full_name='Ydb.Coordination.SessionResponse.acquire_semaphore_pending', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquire_semaphore_result', full_name='Ydb.Coordination.SessionResponse.acquire_semaphore_result', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_semaphore_result', full_name='Ydb.Coordination.SessionResponse.release_semaphore_result', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='describe_semaphore_result', full_name='Ydb.Coordination.SessionResponse.describe_semaphore_result', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='describe_semaphore_changed', full_name='Ydb.Coordination.SessionResponse.describe_semaphore_changed', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_semaphore_result', full_name='Ydb.Coordination.SessionResponse.create_semaphore_result', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_semaphore_result', full_name='Ydb.Coordination.SessionResponse.update_semaphore_result', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_semaphore_result', full_name='Ydb.Coordination.SessionResponse.delete_semaphore_result', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_16', full_name='Ydb.Coordination.SessionResponse.unsupported_16', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_17', full_name='Ydb.Coordination.SessionResponse.unsupported_17', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsupported_18', full_name='Ydb.Coordination.SessionResponse.unsupported_18', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SESSIONRESPONSE_PINGPONG, _SESSIONRESPONSE_FAILURE, _SESSIONRESPONSE_SESSIONSTARTED, _SESSIONRESPONSE_SESSIONSTOPPED, _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING, _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT, _SESSIONRESPONSE_RELEASESEMAPHORERESULT, _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT, _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED, _SESSIONRESPONSE_CREATESEMAPHORERESULT, _SESSIONRESPONSE_UPDATESEMAPHORERESULT, _SESSIONRESPONSE_DELETESEMAPHORERESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='Ydb.Coordination.SessionResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2663,
  serialized_end=5306,
)


_CREATENODEREQUEST = _descriptor.Descriptor(
  name='CreateNodeRequest',
  full_name='Ydb.Coordination.CreateNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.CreateNodeRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.Coordination.CreateNodeRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Coordination.CreateNodeRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5309,
  serialized_end=5443,
)


_CREATENODERESPONSE = _descriptor.Descriptor(
  name='CreateNodeResponse',
  full_name='Ydb.Coordination.CreateNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Coordination.CreateNodeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5445,
  serialized_end=5511,
)


_ALTERNODEREQUEST = _descriptor.Descriptor(
  name='AlterNodeRequest',
  full_name='Ydb.Coordination.AlterNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.AlterNodeRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.Coordination.AlterNodeRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Coordination.AlterNodeRequest.operation_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5514,
  serialized_end=5647,
)


_ALTERNODERESPONSE = _descriptor.Descriptor(
  name='AlterNodeResponse',
  full_name='Ydb.Coordination.AlterNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Coordination.AlterNodeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5649,
  serialized_end=5714,
)


_DROPNODEREQUEST = _descriptor.Descriptor(
  name='DropNodeRequest',
  full_name='Ydb.Coordination.DropNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.DropNodeRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Coordination.DropNodeRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5716,
  serialized_end=5806,
)


_DROPNODERESPONSE = _descriptor.Descriptor(
  name='DropNodeResponse',
  full_name='Ydb.Coordination.DropNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Coordination.DropNodeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5808,
  serialized_end=5872,
)


_DESCRIBENODEREQUEST = _descriptor.Descriptor(
  name='DescribeNodeRequest',
  full_name='Ydb.Coordination.DescribeNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Coordination.DescribeNodeRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Coordination.DescribeNodeRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5874,
  serialized_end=5968,
)


_DESCRIBENODERESPONSE = _descriptor.Descriptor(
  name='DescribeNodeResponse',
  full_name='Ydb.Coordination.DescribeNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Coordination.DescribeNodeResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5970,
  serialized_end=6038,
)


_DESCRIBENODERESULT = _descriptor.Descriptor(
  name='DescribeNodeResult',
  full_name='Ydb.Coordination.DescribeNodeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Coordination.DescribeNodeResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Ydb.Coordination.DescribeNodeResult.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6040,
  serialized_end=6135,
)

_CONFIG.fields_by_name['read_consistency_mode'].enum_type = _CONSISTENCYMODE
_CONFIG.fields_by_name['attach_consistency_mode'].enum_type = _CONSISTENCYMODE
_CONFIG.fields_by_name['rate_limiter_counters_mode'].enum_type = _RATELIMITERCOUNTERSMODE
_SEMAPHOREDESCRIPTION.fields_by_name['owners'].message_type = _SEMAPHORESESSION
_SEMAPHOREDESCRIPTION.fields_by_name['waiters'].message_type = _SEMAPHORESESSION
_SESSIONREQUEST_PINGPONG.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_SESSIONSTART.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_SESSIONSTOP.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_ACQUIRESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_RELEASESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_DESCRIBESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_CREATESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_UPDATESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST_DELETESEMAPHORE.containing_type = _SESSIONREQUEST
_SESSIONREQUEST.fields_by_name['ping'].message_type = _SESSIONREQUEST_PINGPONG
_SESSIONREQUEST.fields_by_name['pong'].message_type = _SESSIONREQUEST_PINGPONG
_SESSIONREQUEST.fields_by_name['session_start'].message_type = _SESSIONREQUEST_SESSIONSTART
_SESSIONREQUEST.fields_by_name['session_stop'].message_type = _SESSIONREQUEST_SESSIONSTOP
_SESSIONREQUEST.fields_by_name['unsupported_5'].message_type = _UNSUPPORTED
_SESSIONREQUEST.fields_by_name['unsupported_6'].message_type = _UNSUPPORTED
_SESSIONREQUEST.fields_by_name['acquire_semaphore'].message_type = _SESSIONREQUEST_ACQUIRESEMAPHORE
_SESSIONREQUEST.fields_by_name['release_semaphore'].message_type = _SESSIONREQUEST_RELEASESEMAPHORE
_SESSIONREQUEST.fields_by_name['describe_semaphore'].message_type = _SESSIONREQUEST_DESCRIBESEMAPHORE
_SESSIONREQUEST.fields_by_name['create_semaphore'].message_type = _SESSIONREQUEST_CREATESEMAPHORE
_SESSIONREQUEST.fields_by_name['update_semaphore'].message_type = _SESSIONREQUEST_UPDATESEMAPHORE
_SESSIONREQUEST.fields_by_name['delete_semaphore'].message_type = _SESSIONREQUEST_DELETESEMAPHORE
_SESSIONREQUEST.fields_by_name['unsupported_13'].message_type = _UNSUPPORTED
_SESSIONREQUEST.fields_by_name['unsupported_14'].message_type = _UNSUPPORTED
_SESSIONREQUEST.fields_by_name['unsupported_15'].message_type = _UNSUPPORTED
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['ping'])
_SESSIONREQUEST.fields_by_name['ping'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['pong'])
_SESSIONREQUEST.fields_by_name['pong'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['session_start'])
_SESSIONREQUEST.fields_by_name['session_start'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['session_stop'])
_SESSIONREQUEST.fields_by_name['session_stop'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['unsupported_5'])
_SESSIONREQUEST.fields_by_name['unsupported_5'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['unsupported_6'])
_SESSIONREQUEST.fields_by_name['unsupported_6'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['acquire_semaphore'])
_SESSIONREQUEST.fields_by_name['acquire_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['release_semaphore'])
_SESSIONREQUEST.fields_by_name['release_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['describe_semaphore'])
_SESSIONREQUEST.fields_by_name['describe_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['create_semaphore'])
_SESSIONREQUEST.fields_by_name['create_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['update_semaphore'])
_SESSIONREQUEST.fields_by_name['update_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['delete_semaphore'])
_SESSIONREQUEST.fields_by_name['delete_semaphore'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['unsupported_13'])
_SESSIONREQUEST.fields_by_name['unsupported_13'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['unsupported_14'])
_SESSIONREQUEST.fields_by_name['unsupported_14'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONREQUEST.oneofs_by_name['request'].fields.append(
  _SESSIONREQUEST.fields_by_name['unsupported_15'])
_SESSIONREQUEST.fields_by_name['unsupported_15'].containing_oneof = _SESSIONREQUEST.oneofs_by_name['request']
_SESSIONRESPONSE_PINGPONG.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_FAILURE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_FAILURE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_FAILURE.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_SESSIONSTARTED.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_SESSIONSTOPPED.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_ACQUIRESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_ACQUIRESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_ACQUIRESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_RELEASESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_RELEASESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_RELEASESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_DESCRIBESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_DESCRIBESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_DESCRIBESEMAPHORERESULT.fields_by_name['semaphore_description'].message_type = _SEMAPHOREDESCRIPTION
_SESSIONRESPONSE_DESCRIBESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_CREATESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_CREATESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_CREATESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_UPDATESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_UPDATESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_UPDATESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE_DELETESEMAPHORERESULT.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONRESPONSE_DELETESEMAPHORERESULT.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONRESPONSE_DELETESEMAPHORERESULT.containing_type = _SESSIONRESPONSE
_SESSIONRESPONSE.fields_by_name['ping'].message_type = _SESSIONRESPONSE_PINGPONG
_SESSIONRESPONSE.fields_by_name['pong'].message_type = _SESSIONRESPONSE_PINGPONG
_SESSIONRESPONSE.fields_by_name['failure'].message_type = _SESSIONRESPONSE_FAILURE
_SESSIONRESPONSE.fields_by_name['session_started'].message_type = _SESSIONRESPONSE_SESSIONSTARTED
_SESSIONRESPONSE.fields_by_name['session_stopped'].message_type = _SESSIONRESPONSE_SESSIONSTOPPED
_SESSIONRESPONSE.fields_by_name['unsupported_6'].message_type = _UNSUPPORTED
_SESSIONRESPONSE.fields_by_name['unsupported_7'].message_type = _UNSUPPORTED
_SESSIONRESPONSE.fields_by_name['acquire_semaphore_pending'].message_type = _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING
_SESSIONRESPONSE.fields_by_name['acquire_semaphore_result'].message_type = _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['release_semaphore_result'].message_type = _SESSIONRESPONSE_RELEASESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['describe_semaphore_result'].message_type = _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['describe_semaphore_changed'].message_type = _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED
_SESSIONRESPONSE.fields_by_name['create_semaphore_result'].message_type = _SESSIONRESPONSE_CREATESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['update_semaphore_result'].message_type = _SESSIONRESPONSE_UPDATESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['delete_semaphore_result'].message_type = _SESSIONRESPONSE_DELETESEMAPHORERESULT
_SESSIONRESPONSE.fields_by_name['unsupported_16'].message_type = _UNSUPPORTED
_SESSIONRESPONSE.fields_by_name['unsupported_17'].message_type = _UNSUPPORTED
_SESSIONRESPONSE.fields_by_name['unsupported_18'].message_type = _UNSUPPORTED
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['ping'])
_SESSIONRESPONSE.fields_by_name['ping'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['pong'])
_SESSIONRESPONSE.fields_by_name['pong'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['failure'])
_SESSIONRESPONSE.fields_by_name['failure'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['session_started'])
_SESSIONRESPONSE.fields_by_name['session_started'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['session_stopped'])
_SESSIONRESPONSE.fields_by_name['session_stopped'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['unsupported_6'])
_SESSIONRESPONSE.fields_by_name['unsupported_6'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['unsupported_7'])
_SESSIONRESPONSE.fields_by_name['unsupported_7'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['acquire_semaphore_pending'])
_SESSIONRESPONSE.fields_by_name['acquire_semaphore_pending'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['acquire_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['acquire_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['release_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['release_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['describe_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['describe_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['describe_semaphore_changed'])
_SESSIONRESPONSE.fields_by_name['describe_semaphore_changed'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['create_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['create_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['update_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['update_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['delete_semaphore_result'])
_SESSIONRESPONSE.fields_by_name['delete_semaphore_result'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['unsupported_16'])
_SESSIONRESPONSE.fields_by_name['unsupported_16'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['unsupported_17'])
_SESSIONRESPONSE.fields_by_name['unsupported_17'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_SESSIONRESPONSE.oneofs_by_name['response'].fields.append(
  _SESSIONRESPONSE.fields_by_name['unsupported_18'])
_SESSIONRESPONSE.fields_by_name['unsupported_18'].containing_oneof = _SESSIONRESPONSE.oneofs_by_name['response']
_CREATENODEREQUEST.fields_by_name['config'].message_type = _CONFIG
_CREATENODEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATENODERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_ALTERNODEREQUEST.fields_by_name['config'].message_type = _CONFIG
_ALTERNODEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERNODERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPNODEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPNODERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBENODEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBENODERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBENODERESULT.fields_by_name['self'].message_type = protos_dot_ydb__scheme__pb2._ENTRY
_DESCRIBENODERESULT.fields_by_name['config'].message_type = _CONFIG
DESCRIPTOR.message_types_by_name['Unsupported'] = _UNSUPPORTED
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['SessionDescription'] = _SESSIONDESCRIPTION
DESCRIPTOR.message_types_by_name['SemaphoreSession'] = _SEMAPHORESESSION
DESCRIPTOR.message_types_by_name['SemaphoreDescription'] = _SEMAPHOREDESCRIPTION
DESCRIPTOR.message_types_by_name['SessionRequest'] = _SESSIONREQUEST
DESCRIPTOR.message_types_by_name['SessionResponse'] = _SESSIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateNodeRequest'] = _CREATENODEREQUEST
DESCRIPTOR.message_types_by_name['CreateNodeResponse'] = _CREATENODERESPONSE
DESCRIPTOR.message_types_by_name['AlterNodeRequest'] = _ALTERNODEREQUEST
DESCRIPTOR.message_types_by_name['AlterNodeResponse'] = _ALTERNODERESPONSE
DESCRIPTOR.message_types_by_name['DropNodeRequest'] = _DROPNODEREQUEST
DESCRIPTOR.message_types_by_name['DropNodeResponse'] = _DROPNODERESPONSE
DESCRIPTOR.message_types_by_name['DescribeNodeRequest'] = _DESCRIBENODEREQUEST
DESCRIPTOR.message_types_by_name['DescribeNodeResponse'] = _DESCRIBENODERESPONSE
DESCRIPTOR.message_types_by_name['DescribeNodeResult'] = _DESCRIBENODERESULT
DESCRIPTOR.enum_types_by_name['ConsistencyMode'] = _CONSISTENCYMODE
DESCRIPTOR.enum_types_by_name['RateLimiterCountersMode'] = _RATELIMITERCOUNTERSMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Unsupported = _reflection.GeneratedProtocolMessageType('Unsupported', (_message.Message,), {
  'DESCRIPTOR' : _UNSUPPORTED,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.Unsupported)
  })
_sym_db.RegisterMessage(Unsupported)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.Config)
  })
_sym_db.RegisterMessage(Config)

SessionDescription = _reflection.GeneratedProtocolMessageType('SessionDescription', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONDESCRIPTION,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionDescription)
  })
_sym_db.RegisterMessage(SessionDescription)

SemaphoreSession = _reflection.GeneratedProtocolMessageType('SemaphoreSession', (_message.Message,), {
  'DESCRIPTOR' : _SEMAPHORESESSION,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.SemaphoreSession)
  })
_sym_db.RegisterMessage(SemaphoreSession)

SemaphoreDescription = _reflection.GeneratedProtocolMessageType('SemaphoreDescription', (_message.Message,), {
  'DESCRIPTOR' : _SEMAPHOREDESCRIPTION,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.SemaphoreDescription)
  })
_sym_db.RegisterMessage(SemaphoreDescription)

SessionRequest = _reflection.GeneratedProtocolMessageType('SessionRequest', (_message.Message,), {

  'PingPong' : _reflection.GeneratedProtocolMessageType('PingPong', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_PINGPONG,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.PingPong)
    })
  ,

  'SessionStart' : _reflection.GeneratedProtocolMessageType('SessionStart', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_SESSIONSTART,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.SessionStart)
    })
  ,

  'SessionStop' : _reflection.GeneratedProtocolMessageType('SessionStop', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_SESSIONSTOP,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.SessionStop)
    })
  ,

  'AcquireSemaphore' : _reflection.GeneratedProtocolMessageType('AcquireSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_ACQUIRESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.AcquireSemaphore)
    })
  ,

  'ReleaseSemaphore' : _reflection.GeneratedProtocolMessageType('ReleaseSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_RELEASESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.ReleaseSemaphore)
    })
  ,

  'DescribeSemaphore' : _reflection.GeneratedProtocolMessageType('DescribeSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_DESCRIBESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.DescribeSemaphore)
    })
  ,

  'CreateSemaphore' : _reflection.GeneratedProtocolMessageType('CreateSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_CREATESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.CreateSemaphore)
    })
  ,

  'UpdateSemaphore' : _reflection.GeneratedProtocolMessageType('UpdateSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_UPDATESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.UpdateSemaphore)
    })
  ,

  'DeleteSemaphore' : _reflection.GeneratedProtocolMessageType('DeleteSemaphore', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONREQUEST_DELETESEMAPHORE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest.DeleteSemaphore)
    })
  ,
  'DESCRIPTOR' : _SESSIONREQUEST,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionRequest)
  })
_sym_db.RegisterMessage(SessionRequest)
_sym_db.RegisterMessage(SessionRequest.PingPong)
_sym_db.RegisterMessage(SessionRequest.SessionStart)
_sym_db.RegisterMessage(SessionRequest.SessionStop)
_sym_db.RegisterMessage(SessionRequest.AcquireSemaphore)
_sym_db.RegisterMessage(SessionRequest.ReleaseSemaphore)
_sym_db.RegisterMessage(SessionRequest.DescribeSemaphore)
_sym_db.RegisterMessage(SessionRequest.CreateSemaphore)
_sym_db.RegisterMessage(SessionRequest.UpdateSemaphore)
_sym_db.RegisterMessage(SessionRequest.DeleteSemaphore)

SessionResponse = _reflection.GeneratedProtocolMessageType('SessionResponse', (_message.Message,), {

  'PingPong' : _reflection.GeneratedProtocolMessageType('PingPong', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_PINGPONG,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.PingPong)
    })
  ,

  'Failure' : _reflection.GeneratedProtocolMessageType('Failure', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_FAILURE,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.Failure)
    })
  ,

  'SessionStarted' : _reflection.GeneratedProtocolMessageType('SessionStarted', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_SESSIONSTARTED,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.SessionStarted)
    })
  ,

  'SessionStopped' : _reflection.GeneratedProtocolMessageType('SessionStopped', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_SESSIONSTOPPED,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.SessionStopped)
    })
  ,

  'AcquireSemaphorePending' : _reflection.GeneratedProtocolMessageType('AcquireSemaphorePending', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.AcquireSemaphorePending)
    })
  ,

  'AcquireSemaphoreResult' : _reflection.GeneratedProtocolMessageType('AcquireSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.AcquireSemaphoreResult)
    })
  ,

  'ReleaseSemaphoreResult' : _reflection.GeneratedProtocolMessageType('ReleaseSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_RELEASESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.ReleaseSemaphoreResult)
    })
  ,

  'DescribeSemaphoreResult' : _reflection.GeneratedProtocolMessageType('DescribeSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.DescribeSemaphoreResult)
    })
  ,

  'DescribeSemaphoreChanged' : _reflection.GeneratedProtocolMessageType('DescribeSemaphoreChanged', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.DescribeSemaphoreChanged)
    })
  ,

  'CreateSemaphoreResult' : _reflection.GeneratedProtocolMessageType('CreateSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_CREATESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.CreateSemaphoreResult)
    })
  ,

  'UpdateSemaphoreResult' : _reflection.GeneratedProtocolMessageType('UpdateSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_UPDATESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.UpdateSemaphoreResult)
    })
  ,

  'DeleteSemaphoreResult' : _reflection.GeneratedProtocolMessageType('DeleteSemaphoreResult', (_message.Message,), {
    'DESCRIPTOR' : _SESSIONRESPONSE_DELETESEMAPHORERESULT,
    '__module__' : 'protos.ydb_coordination_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse.DeleteSemaphoreResult)
    })
  ,
  'DESCRIPTOR' : _SESSIONRESPONSE,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.SessionResponse)
  })
_sym_db.RegisterMessage(SessionResponse)
_sym_db.RegisterMessage(SessionResponse.PingPong)
_sym_db.RegisterMessage(SessionResponse.Failure)
_sym_db.RegisterMessage(SessionResponse.SessionStarted)
_sym_db.RegisterMessage(SessionResponse.SessionStopped)
_sym_db.RegisterMessage(SessionResponse.AcquireSemaphorePending)
_sym_db.RegisterMessage(SessionResponse.AcquireSemaphoreResult)
_sym_db.RegisterMessage(SessionResponse.ReleaseSemaphoreResult)
_sym_db.RegisterMessage(SessionResponse.DescribeSemaphoreResult)
_sym_db.RegisterMessage(SessionResponse.DescribeSemaphoreChanged)
_sym_db.RegisterMessage(SessionResponse.CreateSemaphoreResult)
_sym_db.RegisterMessage(SessionResponse.UpdateSemaphoreResult)
_sym_db.RegisterMessage(SessionResponse.DeleteSemaphoreResult)

CreateNodeRequest = _reflection.GeneratedProtocolMessageType('CreateNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEREQUEST,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.CreateNodeRequest)
  })
_sym_db.RegisterMessage(CreateNodeRequest)

CreateNodeResponse = _reflection.GeneratedProtocolMessageType('CreateNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODERESPONSE,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.CreateNodeResponse)
  })
_sym_db.RegisterMessage(CreateNodeResponse)

AlterNodeRequest = _reflection.GeneratedProtocolMessageType('AlterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALTERNODEREQUEST,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.AlterNodeRequest)
  })
_sym_db.RegisterMessage(AlterNodeRequest)

AlterNodeResponse = _reflection.GeneratedProtocolMessageType('AlterNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERNODERESPONSE,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.AlterNodeResponse)
  })
_sym_db.RegisterMessage(AlterNodeResponse)

DropNodeRequest = _reflection.GeneratedProtocolMessageType('DropNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPNODEREQUEST,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.DropNodeRequest)
  })
_sym_db.RegisterMessage(DropNodeRequest)

DropNodeResponse = _reflection.GeneratedProtocolMessageType('DropNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPNODERESPONSE,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.DropNodeResponse)
  })
_sym_db.RegisterMessage(DropNodeResponse)

DescribeNodeRequest = _reflection.GeneratedProtocolMessageType('DescribeNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBENODEREQUEST,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.DescribeNodeRequest)
  })
_sym_db.RegisterMessage(DescribeNodeRequest)

DescribeNodeResponse = _reflection.GeneratedProtocolMessageType('DescribeNodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBENODERESPONSE,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.DescribeNodeResponse)
  })
_sym_db.RegisterMessage(DescribeNodeResponse)

DescribeNodeResult = _reflection.GeneratedProtocolMessageType('DescribeNodeResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBENODERESULT,
  '__module__' : 'protos.ydb_coordination_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Coordination.DescribeNodeResult)
  })
_sym_db.RegisterMessage(DescribeNodeResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from ydb import scheme


class SchemeClient(scheme.BaseSchemeClient):
    def __init__(self, driver):
        super(SchemeClient, self).__init__(driver)

    async def make_directory(self, path, settings=None):
        return await super(SchemeClient, self).make_directory(path, settings)

    async def remove_directory(self, path, settings=None):
        return await super(SchemeClient, self).remove_directory(path, settings)

    async def list_directory(self, path, settings=None):
        return await super(SchemeClient, self).list_directory(path, settings)

    async def describe_path(self, path, settings=None):
        return await super(SchemeClient, self).describe_path(path, settings)

    async def modify_permissions(self, path, settings):
        return await super(SchemeClient, self).modify_permissions(path, settings)
